@@ -11,7 +11,7 @@ class Review(models.Model):
     entity = models.TextField(blank=True, max_length=80)
     citation = models.TextField(blank=True, max_length=255)
     url = models.URLField(blank=True)
-    moneyquote = RichTextField(max_length=700)
+    moneyquote = RichTextField(max_length=700,default='')
     body = RichTextField()
 
     def __unicode__(self):
